@@ -3,8 +3,9 @@ import logging
 
 from yachalk import chalk
 
-from magnus.interaction import (get_from_catalog, get_parameter, get_secret,
-                                put_in_catalog, store_parameter, track_this)
+from magnus.interaction import (get_from_catalog, get_parameter, get_run_id,
+                                get_secret, put_in_catalog, store_parameter,
+                                track_this)
 
 chalk_colors = {
     'debug': chalk.grey,
